﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;

namespace UltraChartColumnChartAppearance
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            // DataSource
            DataTable dt = new DataTable();
            dt.Columns.Add("Items", typeof(string));
            dt.Columns.Add("Miles Column", typeof(decimal));
            dt.Columns.Add("Fillups Column", typeof(decimal));

            dt.Rows.Add("Item 1", 110, 20);
            dt.Rows.Add("Item 2", 115, 30);
            dt.Rows.Add("Item 3", 120, 40);
            dt.Rows.Add("Item 4", 125, 55);


            ultraChart1.ChartType = ChartType.Composite;
            ultraChart1.BackColor = Color.Black;
            ultraChart1.Data.ZeroAligned = true;
            ultraChart1.TitleTop.Text = "Miles to Fillups Analysis";
            ultraChart1.TitleTop.FontColor = Color.Yellow;
            ultraChart1.TitleTop.Font = new Font("Arial", 14.0F);
            ultraChart1.TitleTop.HorizontalAlign = StringAlignment.Center;


            // Create the Chart Area
            ChartArea area = new ChartArea();
            area.BoundsMeasureType = MeasureType.Percentage;
            area.Bounds = new Rectangle(25, 10, 74, 90);
            area.Border.Thickness = 0;


            AxisItem xAxis = new AxisItem();
            xAxis.OrientationType = AxisNumber.X_Axis;
            xAxis.DataType = AxisDataType.String;
            xAxis.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            xAxis.LineColor = Color.White;
            xAxis.Labels.SeriesLabels.Visible = false;
            xAxis.Labels.Visible = false;
            xAxis.MajorGridLines.Visible = false;
            xAxis.RangeType = AxisRangeType.Custom;
            xAxis.RangeMin = -1;
            xAxis.RangeMax = 8;


            AxisItem yAxis = new AxisItem();
            yAxis.OrientationType = AxisNumber.Y_Axis;
            yAxis.Extent = 60;
            yAxis.TickmarkStyle = AxisTickStyle.Smart;
            yAxis.DataType = AxisDataType.Numeric;
            yAxis.LineColor = Color.White;
            yAxis.Labels.FontColor = Color.White;
            yAxis.Labels.ItemFormatString = "<DATA_VALUE:#0.00 ->";
            yAxis.Labels.HorizontalAlign = StringAlignment.Far;
            yAxis.RangeType = AxisRangeType.Custom;
            yAxis.RangeMin = 100;
            yAxis.RangeMax = 200;


            // One possible approach could be if you have the values in percents
            // in this case we will use only FormatString
            // For example.
            // Here are our values, so let`s add the Percent sign

            AxisItem y2Axis = new AxisItem();
            y2Axis.OrientationType = AxisNumber.Y2_Axis;
            y2Axis.Extent = 50;
            y2Axis.TickmarkStyle = AxisTickStyle.Smart;
            y2Axis.MajorGridLines.Visible = false;
            y2Axis.DataType = AxisDataType.Numeric;
            y2Axis.LineColor = Color.White;
            y2Axis.Labels.FontColor = Color.White;
            y2Axis.Labels.ItemFormatString = "<DATA_VALUE:- #0.00>%";
            y2Axis.RangeType = AxisRangeType.Custom;
            y2Axis.RangeMin = 0;
            y2Axis.RangeMax = 60;


            NumericSeries columnSeries = new NumericSeries();
            columnSeries.DataBind(dt, "Miles Column", "Items");
            columnSeries.PEs.Add(new PaintElement(Color.Gold));
            columnSeries.Label = "Miles [nm]";


            NumericSeries columnSeries2 = new NumericSeries();
            columnSeries2.DataBind(dt, "Fillups Column", "Items");
            columnSeries2.PEs.Add(new PaintElement(Color.Red));
            columnSeries2.Label = "Fillups [fl]";

            ChartLayerAppearance ColumnLayer = new ChartLayerAppearance();
            ColumnLayer.ChartType = ChartType.ColumnChart;
            ColumnLayer.Series.Add(columnSeries);
            ColumnLayer.ChartArea = area;
            ColumnLayer.AxisX = xAxis;
            ColumnLayer.AxisY = yAxis;
            ColumnLayer.AxisY2 = y2Axis;
            ColumnLayer.SwapRowsAndColumns = true;

            ChartLayerAppearance ColumnLayer2 = new ChartLayerAppearance();
            ColumnLayer2.ChartType = ChartType.ColumnChart;
            ColumnLayer2.Series.Add(columnSeries2);
            ColumnLayer2.ChartArea = area;
            ColumnLayer2.AxisX = xAxis;
            ColumnLayer2.AxisY = y2Axis;
            ColumnLayer2.SwapRowsAndColumns = true;

            area.Axes.Add(xAxis);
            area.Axes.Add(yAxis);
            area.Axes.Add(y2Axis);
            ultraChart1.CompositeChart.ChartAreas.Add(area);
            ultraChart1.CompositeChart.ChartLayers.Add(ColumnLayer);
            ultraChart1.CompositeChart.ChartLayers.Add(ColumnLayer2);
            ultraChart1.CompositeChart.Series.Add(columnSeries);
            ultraChart1.CompositeChart.Series.Add(columnSeries2);

            BoxAnnotation AxisYLabel = new BoxAnnotation();
            AxisYLabel.Text = "Miles";
            AxisYLabel.Border.Color = Color.Transparent;
            AxisYLabel.FillColor = ultraChart1.BackColor;
            AxisYLabel.TextStyle.FontColor = Color.White;
            AxisYLabel.Location.Type = LocationType.Percentage;
            AxisYLabel.Location.LocationX = area.Bounds.X + 2;
            AxisYLabel.Location.LocationY = area.Bounds.Y - 2;
            ultraChart1.Annotations.Annotations.Add(AxisYLabel);


            BoxAnnotation AxisY2Label = new BoxAnnotation();
            AxisY2Label.Text = "Fillups";
            AxisY2Label.Width = -1;
            AxisY2Label.TextStyle.HorizontalAlign = StringAlignment.Far;
            AxisY2Label.Border.Color = Color.Transparent;
            AxisY2Label.FillColor = ultraChart1.BackColor;
            AxisY2Label.TextStyle.FontColor = Color.White;
            AxisY2Label.Location.Type = LocationType.Percentage;
            AxisY2Label.Location.LocationX = (area.Bounds.X + area.Bounds.Width) - 4;
            AxisY2Label.Location.LocationY = area.Bounds.Y - 2;
            ultraChart1.Annotations.Annotations.Add(AxisY2Label);
            ultraChart1.Legend.DataAssociation = ChartTypeData.SplitData;


            // Add a Legend
            CompositeLegend m_ChartLegend = new CompositeLegend();
            ColumnLayer.LegendItem = LegendItemType.Auto;
            m_ChartLegend.ChartLayers.Add(ColumnLayer);
            m_ChartLegend.ChartLayers.Add(ColumnLayer2);
            m_ChartLegend.BoundsMeasureType = MeasureType.Percentage;
            m_ChartLegend.Bounds = new Rectangle(1, 10, 18, 20);
            area.BoundsMeasureType = MeasureType.Percentage;
            area.Bounds = new Rectangle(25, 10, 74, 90);
            m_ChartLegend.PE.ElementType = PaintElementType.Gradient;
            m_ChartLegend.PE.FillGradientStyle = GradientStyle.Circular;
            m_ChartLegend.PE.Fill = Color.Yellow;
            m_ChartLegend.PE.FillStopColor = Color.Orange;
            m_ChartLegend.Border.CornerRadius = 10;
            m_ChartLegend.Border.Thickness = 0;
            m_ChartLegend.LabelStyle.FontSizeBestFit = true;
            ultraChart1.CompositeChart.Legends.Add(m_ChartLegend);



            Color[] initColor = new Color[] { Color.Red, Color.Gold };
            this.ultraChart1.ColorModel.CustomPalette = initColor;
        }

        List<Primitive> list;
        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            
            list = new List<Primitive>();
            foreach (Primitive pr in e.SceneGraph)
            {
                Box pl = pr as Box;
                if (pl != null && pl.Series != null && pl.Layer.LayerID == "chartLayer2")
                {
                    pl.rect = new Rectangle(pl.rect.X + (pl.rect.Width / 2) + 3, pl.rect.Y, pl.rect.Width - (pl.rect.Width / 2), pl.rect.Height);
                }
                if (pl != null && pl.Series != null && pl.Layer.LayerID == "chartLayer1")
                {
                    pl.rect = new Rectangle(pl.rect.X, pl.rect.Y, pl.rect.Width - (pl.rect.Width / 2), pl.rect.Height);
                }

                if (pl != null && pl.Series != null && pl.Layer.LayerID == "chartLayer1")
                {
                    Text txt = new Text();
                    txt.PE.Fill = Color.Yellow;// White;
                    txt.SetTextString(pl.Series.Label);
                    txt.bounds.Location = new Point(pl.rect.X + (pl.rect.Width / 2), pl.rect.Y + pl.rect.Height + 10);
                    list.Add(txt);

                    if (list.Count > 1)
                    {
                        Text txtSpliter = new Text();
                        txtSpliter.PE.Fill = Color.White;
                        txtSpliter.SetTextString(pl.Series.Label);
                        txtSpliter.SetTextString("|");
                        txtSpliter.labelStyle.Font = new System.Drawing.Font("Ariel", 14F);
                        txtSpliter.bounds.Location = new Point(pl.rect.X - pl.rect.Width, pl.rect.Y + pl.rect.Height);
                        list.Add(txtSpliter);
                    }
                }
            }

            foreach (Text txt in list) e.SceneGraph.Add(txt);
        }

        private void ultraChart1_DataItemOver(object sender, Infragistics.UltraChart.Shared.Events.ChartDataEventArgs e)
        {
            foreach (Text txt in list)
            {
                if (txt.GetTextString() == e.RowLabel)
                {
                    txt.PE.Fill = Color.Magenta;// Green;
                }
            }
        }

    }
}
